@@ -138,22 +138,22 @@ c       from h1 with the zenith angle cost
        implicit none
        real*8 h1, h2, cost
 
-       real*8 sint, costp, sintp, temp
+       real*8 sint, costp, sintp
+       character*80 text
 
        sint = sqrt(1.d0 - cost**2)
        sintp = h1*sint /h2
-       if(h1 * sint .le. h2) then
-c              
+       if(sintp .le. 1.0d0) then
+
           costp = sqrt(1.d0 - sintp**2)*sign(1.d0, cost)
        else
-          temp= 1.d0 - sintp**2
-          if(temp .ge. 0.d0 ) then
-             costp = -sqrt(1.d0 - sintp**2) *sign(1.d0, cost)
-          elseif(abs(temp) .lt. 1.d-3) then
+          if(abs(1.d0-sintp**2) .lt. 1.d-3) then
              costp = 0.
           else
+             write(text, *) 'h1, h2, cost=', h1, h2, cost
+             call cerrorMsg(text, 1)
              call
-     *       cerrorMsg('h1,h2,cosz invalid at clenbetwee2h', 0)
+     *       cerrorMsg('h1,h2,cost invalid at clenbetwee2h', 0)
           endif 
        endif
 c
