@@ -77,9 +77,13 @@ c     *    +  s**4/rp/rp/8.d0*cosp*(1.d0-cosp**2)    ! negligible
 c     *     - s**4/4.d0/rp*cosp*(1.d0-cosp**2)   ! negligible
 
 c----------------------------------------------------------------------
-      t = min(tin, maxkgm2)
-      if(t .eq. maxkgm2) then
-         jcut= 1
+      if(OneDim .eq. 0) then
+         t = min(tin, maxkgm2)
+         if(t .eq. maxkgm2) then
+            jcut= 1
+         else
+            jcut = 0
+         endif
       else
          jcut = 0
       endif
@@ -110,15 +114,16 @@ c                   we shall move by real length rather than by thickness
             endif   
          endif
       else         
-c               max movable thickness
-         t = min(tin, cvh2thick(z)/cutf/(abs(cosz) + .1) )
-         if(t .ne. tin) then
-            jcut =1
-         endif
-c     
+c
          if(OneDim .eq. 1 .and. z .lt. Htop) then
             leng = ct2lTA(z,  t)
          else
+c               max movable thickness
+            t = min(tin, cvh2thick(z)/cutf/(abs(cosz) + .1) )
+            if(t .ne. tin) then
+               jcut =1
+            endif
+
             rho = cvh2den(z)
             rhop = cvh2denp(z)
 c               at very high altitude,  rhop = 0
