@@ -22,5 +22,7 @@
      * LundPara /1, 2, 0, 0, 1, 5*0/,
      * IntModel /'int1'/ ,
      * Efermi /10.e-3/
-       data Eta2Pi0/0.2/
+       data 
+     * Eta2Pi0/0.2/,
+     * SucInt /1/
       end
