@@ -1,7 +1,9 @@
 c                parameters for primary angle sampling
 c	(->	---------------------------------------------------
 
-           complex*16  CosZenith   !1  Range of cos(zenith angle). Say, (0.5, 1.0)
+           complex*16  CosZenith   !1  Range of cos(zenith angle). Say, (0.5, 1.0). Used when Za2ry is 'is' 
+           complex*16  Azimuth     !1  Range of azimuthal angle in deg. Say, (0, 45). Defaulti is (0,360).
+                                   !   Used when Za1ry is 'is'
            character*4 Za1ry       !1  Specify the primary angle sampling method by one of 'is', 'ps' or 'aps'.
                         !   "is" is isotropic. The range is by CosZenith.
                         !   "ps" is for point source (See also SourceDec)
@@ -14,6 +16,6 @@ c	(->	---------------------------------------------------
 
 c	<-)	----------------------------------------------------
 
-           common /Zincident/ CosZenith, SourceDec, Ddelta, HeightOfInj,
-     *                        OffsetHeight
+           common /Zincident/ Azimuth, CosZenith, SourceDec, Ddelta,
+     *      HeightOfInj,  OffsetHeight
            common /Zincidentc/ Za1ry
