@@ -37,7 +37,7 @@ c	(->	--------------------------------------------
             !  <60 ==> x,y, in 'xyz' and z in kg/m2
             !  61-100 ==>  for Cherenkov observation. For Coord system subtract 60.
             !   if the value is even,  binary output is made on TraceDev.
-            !  > 101  ==> The user hook for trace is used.
+            !  > 101  ==> subtract 100 and apply the above, but chookTrace or chookCeren["",S,E] are used.
             !  Primary system:  Origin is the deepest detector.  Z-axis is the primary direction. 
             !                   X-axis is Z x Vertical axis.  X-Y plane is orthogonal to the primary.
             !  Detector system: origin is the deepest detector. Z-axis is the vertical one.  X-axis is 
