@@ -17,7 +17,7 @@ c          ///////////
      * ng(nth, nl), ne(nth, nl), nmu(nth, nl), 
      * nh(nth, nl), ntha
       integer ng, ne, nmu, nh, ntha
-      real*8 eth(nth)
+      real*8 eth
 c     //////////////
 
 c         If you feel writing the parameters on stderr is
@@ -82,7 +82,7 @@ c          ///////////
      * ng(nth, nl), ne(nth, nl), nmu(nth, nl), 
      * nh(nth, nl), ntha
       integer ng, ne, nmu, nh, ntha
-      real*8 eth(nth)
+      real*8 eth
 c     //////////////
 
 
@@ -109,8 +109,8 @@ c      call cwriteSeed
       enddo
       write(*, *)
       call cqIncident(inci, angle)
-      write(*,*) EventNo, inci.p.code, inci.p.fm.e, -angle.r(1),
-     *   -angle.r(2), -angle.r(3)      
+      write(*,'(i7,i4,g13.4,3f10.7)') EventNo, inci.p.code, inci.p.fm.e,
+     *  -angle.r(1),  -angle.r(2), -angle.r(3)      
       end
       subroutine ccount(nc, aTrack)
       implicit none
@@ -126,7 +126,7 @@ c          ///////////
      * ng(nth, nl), ne(nth, nl), nmu(nth, nl),
      * nh(nth, nl), ntha
       integer ng, ne, nmu, nh, ntha
-      real*8 eth(nth)
+      real*8 eth
 c
       integer nc(nth, nl)
 
@@ -168,7 +168,7 @@ c          ///////////
      * ng(nth, nl), ne(nth, nl), nmu(nth, nl), 
      * nh(nth, nl), ntha
       integer ng, ne, nmu, nh, ntha
-      real*8 eth(nth)
+      real*8 eth
 c     //////////////
 
       integer iij
@@ -273,7 +273,7 @@ c          ///////////
      * ng(nth, nl), ne(nth, nl), nmu(nth, nl), 
      * nh(nth, nl), ntha
       integer ng, ne, nmu, nh, ntha
-      real*8 eth(nth)
+      real*8 eth
 c     //////////////
 
 
