@@ -38,6 +38,8 @@ c           (except for hadronic interactions)
             call cintennb
          elseif(MovedTrack.p.code .eq. kddb) then
             call cinteddb
+         elseif(MovedTrack.p.code .eq. keta) then
+            call cinteEta
          else
             write(msg, *) ' ptcl =', MovedTrack.p.code,
      *        ' interaction=', 
