@@ -79,33 +79,39 @@ c                 thick may have been changed to shorter one.
 c               neutral
          rmg = 1.d5
          if(Reverse .eq. 0) then
-            if(TrackBefMove.p.code .eq. kphoton) then
-               if(erg .gt. MagPairEmin .and. MagPair .ne. 0) then
-                  call clengSmallBC(TrackBefMove, rmgmax)  
-                  rmg = min(rmg, rmgmax)
+            if(TrackBefMove.p.code .eq. kneumu .or.
+     *          TrackBefMove.p.code .eq. kneue) then
+               leng = rmg           ! means very large
+               thick = AlmostVacT   ! not used
+            else
+               if(TrackBefMove.p.code .eq. kphoton) then
+                  if(erg .gt. MagPairEmin .and. MagPair .ne. 0) then
+                     call clengSmallBC(TrackBefMove, rmgmax)  
+                     rmg = min(rmg, rmgmax)
+                  endif
                endif
-            endif
-            if(TrackBefMove.p.code .eq. kphoton .and.
-     *          TrackBefMove.p.fm.p(4) .gt. LpmPairEmin .and. 
-     *          LpmEffect) then
-               if(TrackBefMove.pos.height .lt. AlmostVacH) then
-                  ztrunc = TrackBefMove.pos.depth/10.
+               if(TrackBefMove.p.code .eq. kphoton .and.
+     *              TrackBefMove.p.fm.p(4) .gt. LpmPairEmin .and. 
+     *              LpmEffect) then
+                  if(TrackBefMove.pos.height .lt. AlmostVacH) then
+                     ztrunc = TrackBefMove.pos.depth/10.
+                  else
+                     ztrunc = AlmostVacT  
+                  endif
                else
-                  ztrunc = AlmostVacT  
+                  ztrunc = X0*5
                endif
-            else
-               ztrunc = X0*5
-            endif
-            call cthick2len(TrackBefMove.pos.height, 
-     *      TrackBefMove.vec.coszenith, ztrunc, leng, thick, jcut)
+               call cthick2len(TrackBefMove.pos.height, 
+     *         TrackBefMove.vec.coszenith, ztrunc, leng, thick, jcut)
 c                 thick may have been changed to shorter one.
-            if(rmg .lt. leng) then
-               thick = clen2thick(TrackBefMove.pos.height,
-     *           TrackBefMove.vec.coszenith, rmg)
-               leng = rmg
-            else
-               thick = AlmostVacT
-               leng = rmg
+               if(rmg .lt. leng) then
+                  thick = clen2thick(TrackBefMove.pos.height,
+     *            TrackBefMove.vec.coszenith, rmg)
+                  leng = rmg
+               else
+                  thick = AlmostVacT   ! not used.
+                  leng = rmg           ! meas very large
+               endif
             endif
          elseif(Reverse .eq. 1) then
             leng = rmg
