@@ -75,6 +75,7 @@ c -------------------------------------tracking a ptcl
 #include  "Ztrackv.h"
 #include  "Ztrackp.h"
 #include  "Zobs.h"
+#include  "Zobsp.h"
 #include  "Zobsv.h"
 #include  "Zincidentv.h"
 #include  "Zcode.h"
@@ -82,6 +83,7 @@ c -------------------------------------tracking a ptcl
 c                next is for DEBUG
 #include  "Zcondc.h"
 
+      real*8 cosangle
       character*70 msg
 cc      integer icon
 
@@ -111,6 +113,7 @@ c           mag. deflection.  Path end inf is set in MovedTrack
 c           see if MovedTrack crosses an observation site.
 c         (or reaches BorderHeightL)  If so, reset MovedTrack. 
             call cifXObsSite
+
 #if DEBUG == 4
             call checkstat('after cifXObsSite')
 #endif
@@ -158,11 +161,37 @@ c                  (at AS generation, some ptcl may have < KEminObs)
                call cobservation(2)
             endif
 c               update observation place
-            MovedTrack.where = MovedTrack.where + 1
-c            if(MovedTrack.where .le. NoOfSites) then
-            if(MovedTrack.where .le. EndLevel) then  ! 96.09.18
+            if(ObsPlane .eq. horizontal) then
+               cosangle = MovedTrack.vec.coszenith
+            elseif(ObsPlane .eq. perpendicular) then
+               call cscalerProd(MovedTrack.vec.w, DcAtObsXyz,
+     *               cosangle)
+            else
+               call 
+     *         cerrorMsg('should not come here in tracking', 0)
+            endif
+
+            if(cosangle .lt. 0.) then
+               MovedTrack.where = MovedTrack.where - 1
+            else
+               MovedTrack.where = MovedTrack.where + 1
+            endif
 c                  if more obs-site, stack current ptcl.
-               call cpush(MovedTrack)
+            if(.not. Upgoing) then  ! downgoing
+               if(MovedTrack.where .gt. EndLevel) then
+                  ! no need to stack; discard ptcl.
+               else
+                  MovedTrack.where =max( MovedTrack.where, 1)
+                  call cpush(MovedTrack)
+               endif
+            else    ! Upgoing
+               if(MovedTrack.where .lt.1 ) then
+                   ! no need to stack
+               else
+                  MovedTrack.where =
+     *                         min(MovedTrack.where, EndLevel)
+                  call cpush(MovedTrack)
+               endif
             endif
          elseif(MoveStat .eq. BorderL) then
             call cobservation(3)
